Setting up genomic intervals
===================================================

.. autoclass:: fwdpy11.Region

.. autoclass:: fwdpy11.Sregion
    
    This class is an ABC derived from :class:`fwdpy11.Region`

.. autoclass:: fwdpy11.ConstantS

.. autoclass:: fwdpy11.UniformS

.. autoclass:: fwdpy11.ExpS

.. autoclass:: fwdpy11.GammaS

.. autoclass:: fwdpy11.GaussianS

.. autoclass:: fwdpy11.MultivariateGaussianEffects

.. autoclass:: fwdpy11.LogNormalS

    .. automethod:: mv

.. autoclass:: fwdpy11.mvDES

.. autoclass:: fwdpy11.GeneticMapUnit

.. autoclass:: fwdpy11.PoissonInterval

    This class inherits from :class:`fwdpy11.GeneticMapUnit`

.. autoclass:: fwdpy11.PoissonPoint

    This class inherits from :class:`fwdpy11.GeneticMapUnit`

.. autoclass:: fwdpy11.BinomialPoint

    This class inherits from :class:`fwdpy11.GeneticMapUnit`

.. autoclass:: fwdpy11.FixedCrossovers

    This class inherits from :class:`fwdpy11.GeneticMapUnit`

.. autoclass:: fwdpy11.BinomialInterval

    This class inherits from :class:`fwdpy11.GeneticMapUnit`
